/*
  'Ridge' kwin client
  file: Ridge.h
  date: 08.12.2003

  (c) 2003 Jens Luetkens <j.luetkens@limitland.de>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#ifndef KWIN_RIDGE_H
#define KWIN_RIDGE_H

#include <qptrlist.h>

#include <kwin/client.h>

#include <kpixmap.h>
#include <kpixmapeffect.h>

#include "Ridge.h"


class QBoxLayout;
class QSpacerItem;

namespace KWinInternal
{
class RidgeButton;

class Ridge : public KWinInternal::Client
{
	Q_OBJECT

public:

	Ridge
	(
	    Workspace *,
	    WId,
	    bool tool,
	    QWidget * parent = 0,
	    const char * name = 0
	);

	~Ridge();

	void			insetRect(QRect *rect, int inset);
	void			decorateRidgeRect(QRect rect, QPainter * p, QColor backgroundColor, bool fill);
	void			frameRidgeRect(QRect rect, QPainter * p);

	/* Configuration */
    bool			m_hasBorder;
    int				m_borderSize;
    bool			m_hasOffset;
    int				m_offsetSize;
    bool			m_hasDecoration;
	QString			m_decorationTheme;
    bool			m_hasOutline;
	QColor			m_outlineAColor;
	QColor			m_outlineIColor;
	

protected:

	virtual void paintEvent(QPaintEvent *);
	virtual void mouseDoubleClickEvent(QMouseEvent *);
	virtual void stickyChange(bool b);
	virtual void maximizeChange(bool);
	virtual void activeChange(bool);

protected slots:

	void slotReset();

signals:

	void stkyChange(bool);
	void maxChange(bool);

private:

	enum ButtonType
	{
	    ButtonHelp,
	    ButtonSticky,
	    ButtonMenu,
	    ButtonSeparator,
	    ButtonIconify,
	    ButtonMaximize,
	    ButtonClose,
	    ButtonLower
	};

	bool			tool_;		/* not used */
	bool			hasMenu;

	RidgeButton *   createButton(const QString &);
	void			createButtons();
	void			resetLayout();
	void			repaintButtons();
	void			someGeometry();

	QPixmap			menuIcon;
	QPixmap			backgroundTile;
   	KPixmap			tempPixmap;
	
	/* some geometry */
	QRect			titleRect;
	uint			titleWidth;
	uint			topHeight;
	uint			fontHeight;
	uint			textMargin;
	uint			boxHeight;
	QColor			titleBarColor;
	QColor			titleBlendColor;
	
	/* window layout */
	QBoxLayout		* mainLayout_;
	QSpacerItem		* topSpacer_;
	QPtrList<RidgeButton> leftButtonList_;
	QPtrList<RidgeButton> rightButtonList_;
	
};
}

#endif
// vim:ts=2:sw=2:tw=78:set et:
