/*
  'Ridge' kwin client
  file: RidgeButton.cpp
  date: 08.12.2003

  (c) 2003 Jens Luetkens <j.luetkens@limitland.de>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#include <qpainter.h>
#include <kwin/client.h>
#include <kwin/options.h>


#include <klocale.h>
#include <kpixmap.h>
#include <kpixmapeffect.h>

#include "Ridge.h"
#include "RidgeButton.h"

using namespace KWinInternal;

static unsigned char help_bits[] =			{ 0x18, 0x18, 0x00, 0x1e, 0x10, 0x10, 0x10, 0x10 };
static unsigned char sticky_bits[] =		{ 0x3c, 0x7e, 0xe7, 0xc3, 0xc3, 0xe7, 0x7e, 0x3c };
static unsigned char unsticky_bits[] =		{ 0x3c, 0x7e, 0xe7, 0xdb, 0xdb, 0xe7, 0x7e, 0x3c };
static unsigned char iconify_bits[] =		{ 0x00, 0x00, 0x3c, 0x3c, 0x3c, 0x3c, 0x00, 0x00 };
static unsigned char menu_bits[] =			{ 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55 };
static unsigned char maximize_bits[] =		{ 0xff, 0xff, 0xc3, 0xc3, 0xc3, 0xc3, 0xff, 0xff };
static unsigned char unmaximize_bits[] =	{ 0x00, 0x00, 0xff, 0xff, 0xc3, 0xc3, 0xff, 0xff };
static unsigned char close_bits[] =			{ 0xc3, 0xe7, 0x7e, 0x3c, 0x3c, 0x7e, 0xe7, 0xc3 };
static unsigned char empty_bits[] =			{ 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static const int buttonSize = 				8;
static const int halfbuttonSize = 			4;

RidgeButton::RidgeButton(Ridge * parent, const char *name, const QString& tip)
		: KWinButton (parent, name, tip),
		mouseOver_  (false),
		mouseDown_  (false)
{
	
	if ( name == "help" ) {
		bitmap_ = QBitmap(buttonSize, buttonSize, help_bits, true);
	}
	else if ( name == "menu" ) {
		bitmap_ = QBitmap(buttonSize, buttonSize, menu_bits, true);
	}
	else if ( name == "sticky" ) {
		if ( parent->isSticky() ) {
			bitmap_ = QBitmap(buttonSize, buttonSize, unsticky_bits, true);
		}
		else {
			bitmap_ = QBitmap(buttonSize, buttonSize, sticky_bits, true);
		}
	}
	else if ( name == "iconify" ) {
		bitmap_ = QBitmap(buttonSize, buttonSize, iconify_bits, true);
	}
	else if ( name == "maximize" ) {
		if ( parent->isMaximized() ) {
			bitmap_ = QBitmap(buttonSize, buttonSize, unmaximize_bits, true);
		}
		else {
			bitmap_ = QBitmap(buttonSize, buttonSize, maximize_bits, true);
		}
	}
	else if ( name == "close" ) {
		bitmap_ = QBitmap(buttonSize, buttonSize, close_bits, true);
	}
	else {
		bitmap_ = QBitmap(buttonSize, buttonSize, empty_bits, true);
	}
	
	bitmap_.setMask(bitmap_);

	setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
	setBackgroundMode(NoBackground);
	repaint();
}

RidgeButton::~RidgeButton()
{
	// Empty.
}

//
// slotStickyChange(bool b)
//
void RidgeButton::slotStickyChange(bool b)
{
	if ( b ) {
		bitmap_ = QBitmap(buttonSize, buttonSize, unsticky_bits, true);
	}
	else {
		bitmap_ = QBitmap(buttonSize, buttonSize, sticky_bits, true);
	}
	bitmap_.setMask(bitmap_);

	repaint();
}

//
// slotMaximizeChange(bool b)
//
void RidgeButton::slotMaximizeChange(bool b)
{
	if ( b ) {
		bitmap_ = QBitmap(buttonSize, buttonSize, unmaximize_bits, true);
	}
	else {
		bitmap_ = QBitmap(buttonSize, buttonSize, maximize_bits, true);
	}
	bitmap_.setMask(bitmap_);

	repaint();
}

//
// enterEvent(QEvent * e)
//
void RidgeButton::enterEvent(QEvent * e)
{
	mouseOver_ = true;
	repaint();
	KWinButton::enterEvent(e);
}

//
// leaveEvent(QEvent * e)
//
void RidgeButton::leaveEvent(QEvent * e)
{
	mouseOver_ = false;
	repaint();
	KWinButton::leaveEvent(e);
}

//
// paintEvent(QPaintEvent *)
//
void RidgeButton::paintEvent(QPaintEvent *)
{
	Ridge *client = (Ridge *) parentWidget();

	QPainter p(this);
	QRect buttonRect(rect());

	//tint colors for titlebar
    titleBarColor = options->color(Options::TitleBar, client->isActive());
	
	if ( client->m_hasOutline ) {
		
		client->frameRidgeRect(buttonRect, &p);
		client->insetRect(&buttonRect, 1);

	}
	client->decorateRidgeRect(buttonRect, &p, titleBarColor, true);

	// Draw bitmap icon.
	QPoint center(buttonRect.center());

	p.setBrush(NoBrush);
	p.setPen(options->color(Options::Font, mouseOver_));
	p.drawPixmap(center.x() - halfbuttonSize + 1, center.y() - halfbuttonSize + 1, bitmap_);

}

