/*
  'Ridge' kwin client configuration
  file: config.cpp
  date: 08.12.2003

  (c) 2003 Jens Luetkens <j.luetkens@limitland.de>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#include <qcheckbox.h>

#include <kcolorbutton.h>
#include <knuminput.h>
#include <kcombobox.h>

#include <kconfig.h>
#include <klocale.h>
#include <kglobal.h>

#include "config.h"
#include "configdialog.h"

RidgeConfig::RidgeConfig(KConfig* config, QWidget* parent)
    : QObject(parent), m_config(0), m_dialog(0)
{
    // create the configuration object
    m_config = new KConfig("kwinridgerc");
    KGlobal::locale()->insertCatalogue("kwin_ridge_config");

    // create the configuration dialog
    m_dialog = new ConfigDialog(parent);

    // load the configuration
    load(config);

    // setup the connections
    connect(m_dialog->hasBorder, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->borderSize, SIGNAL(valueChanged(int)),
            this, SIGNAL(changed()));

    connect(m_dialog->hasOffset, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->offsetSize, SIGNAL(valueChanged(int)),
            this, SIGNAL(changed()));

    connect(m_dialog->hasDecoration, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->decorationTheme, SIGNAL(activated(int)),
            this, SIGNAL(changed()));

    connect(m_dialog->hasOutline, SIGNAL(toggled(bool)),
            this, SIGNAL(changed()));
    connect(m_dialog->outlineAColor, SIGNAL(changed(const QColor &)),
            this, SIGNAL(changed()));
    connect(m_dialog->outlineIColor, SIGNAL(changed(const QColor &)),
            this, SIGNAL(changed()));

	// show the dialog
    m_dialog->show();

}

RidgeConfig::~RidgeConfig()
{
    if (m_dialog) delete m_dialog;
    if (m_config) delete m_config;
}

//
// load(KConfig*)
//
void RidgeConfig::load(KConfig*)
{
	QColor defaultColor(0,0,0);

    m_config->setGroup("General");

    bool hasBorder = m_config->readBoolEntry("hasBorder", true);
    m_dialog->hasBorder->setChecked(hasBorder);
    int borderSize = m_config->readNumEntry("borderSize", 3);
    m_dialog->borderSize->setValue(borderSize);

    bool hasOffset = m_config->readBoolEntry("hasOffset", true);
    m_dialog->hasOffset->setChecked(hasOffset);
    int offsetSize = m_config->readNumEntry("offsetSize", 5);
    m_dialog->offsetSize->setValue(offsetSize);

    bool hasDecoration = m_config->readBoolEntry("hasDecoration", true);
    m_dialog->hasDecoration->setChecked(hasDecoration);
	QString decorationTheme = m_config->readEntry("decorationTheme", "Ridge");
	m_dialog->decorationTheme->setCurrentItem(decorationTheme, false , 0);

    bool hasOutline = m_config->readBoolEntry("hasOutline", true);
    m_dialog->hasOutline->setChecked(hasOutline);
	QColor outlineAColor = m_config->readColorEntry("outlineAColor", &defaultColor);
	m_dialog->outlineAColor->setColor(outlineAColor);
	QColor outlineIColor = m_config->readColorEntry("outlineIColor", &defaultColor);
	m_dialog->outlineIColor->setColor(outlineIColor);
}

//
// save(KConfig*)
//
void RidgeConfig::save(KConfig*)
{
    m_config->setGroup("General");

    m_config->writeEntry("hasBorder", m_dialog->hasBorder->isChecked() );
    m_config->writeEntry("borderSize", m_dialog->borderSize->value() );

    m_config->writeEntry("hasOffset", m_dialog->hasOffset->isChecked() );
    m_config->writeEntry("offsetSize", m_dialog->offsetSize->value() );

    m_config->writeEntry("hasDecoration", m_dialog->hasDecoration->isChecked() );
    m_config->writeEntry("decorationTheme", m_dialog->decorationTheme->currentText() );

    m_config->writeEntry("hasOutline", m_dialog->hasOutline->isChecked() );
	m_config->writeEntry("outlineAColor", m_dialog->outlineAColor->color());
	m_config->writeEntry("outlineIColor", m_dialog->outlineIColor->color());

    m_config->sync();
}

//
// defaults()
//
void RidgeConfig::defaults()
{

    m_dialog->hasBorder->setChecked(true);
    m_dialog->borderSize->setValue(3);

    m_dialog->hasOffset->setChecked(true);
    m_dialog->borderSize->setValue(4);

    m_dialog->hasDecoration->setChecked(true);
    m_dialog->decorationTheme->setCurrentItem("Ridge", true, 0);

    m_dialog->hasOutline->setChecked(true);
    m_dialog->outlineAColor->setColor(QColor(0, 0, 0));
    m_dialog->outlineIColor->setColor(QColor(0, 0, 0));

}

//////////////////////////////////////////////////////////////////////////////
// Plugin Stuff                                                             //
//////////////////////////////////////////////////////////////////////////////

extern "C"
{
    QObject* allocate_config(KConfig* config, QWidget* parent) {
        return (new RidgeConfig(config, parent));
    }
}

//#include "config.moc"
